#!/usr/bin/env python3
# -*- coding: utf-8 -*-
#
# === This file is part of calamares-settings steamos ===
#
#   SPDX-FileCopyrightText: 2019-2020 Collabora Ltd <arnaud.ferraris@collabora.com>
#   SPDX-License-Identifier: ISC
#
#   calamares-settings steamos is Free Software: see the License-Identifier above.
#

import os
import shutil

import libcalamares


import gettext
_ = gettext.translation("calamares-python",
                        localedir=libcalamares.utils.gettext_path(),
                        languages=libcalamares.utils.gettext_languages(),
                        fallback=True).gettext


def pretty_name():
    return _("Cleaning up.")

def run():
    root_mount_point = libcalamares.globalstorage.value("rootMountPoint")
    target_etc_dir = root_mount_point + "/var/lib/overlays/etc/"
    target_ssh_dir = target_etc_dir + "upper/ssh/"

    # Clear the machine-id file on the installed system
    machine_id = open(target_etc_dir + "machine-id", "w")
    machine_id.close()

    # Remove SSH host keys on the installed system
    for file in os.listdir(target_ssh_dir):
        if file.startswith("ssh_host") and "key" in file:
            os.remove(target_ssh_dir + file)

    # Cleanup /var/boot, which contains dkms-rebuilt initrd with nvidia drivers.
    # For now, we prefer to discard it, to ensure that the first boot on the installed
    # steamos triggers a fresh dkms build of the nvidia drivers. Also, if we
    # wanted to keep /var/boot, TBH we'd need some more pain with grub-install.
    # I'm not ready for that yet...
    var_boot_dir = os.path.join(root_mount_point, "var", "boot")
    if os.path.exists(var_boot_dir):
        shutil.rmtree(var_boot_dir)

    # Remove the steamos-installer shortcuts on Desktop.
    steamos_install_desktop = os.path.join(root_mount_point, "home", "steamos", "Desktop", "steamos-install.desktop")
    if os.path.exists(steamos_install_desktop):
        os.remove(steamos_install_desktop)
    steamos_install_desktop = os.path.join(root_mount_point, "home", "steamos", "Desktop", "steamos-install-devel.desktop")
    if os.path.exists(steamos_install_desktop):
        os.remove(steamos_install_desktop)


    # Remove copied /home/swapfile since it can have holes and swapon fails:
    # see https://man.archlinux.org/man/swapon.8#Files_with_holes
    home_swapfile = os.path.join(root_mount_point, "home", "swapfile")
    if os.path.exists(home_swapfile):
        os.remove(home_swapfile)

    return None
